@@ -23,7 +23,6 @@ __plugin_usage__ = '''俄罗斯轮盘帮助：
     开始对决：开枪（轮流开枪，30秒未开枪另一方可使用‘结算’命令结束对决并胜利）
     结算：结算（当某一方30秒未开枪，可使用该命令强行结束对决并胜利）
     我的战绩：我的战绩
-    我的金币：我的金币
     排行榜：金币排行/胜场排行/败场排行/欧洲人排行/慈善家排行
     【注：同一时间群内只能有一场对决】
 '''
@@ -32,6 +31,8 @@ scheduler = require("nonebot_plugin_apscheduler").scheduler
 
 driver: nonebot.Driver = nonebot.get_driver()
 
+bot_name = list(driver.config.nickname)[0] if driver.config.nickname else '本裁判'
+
 sign_gold = driver.config.sign_gold if driver.config.sign_gold else [1, 100]
 max_bet_gold = driver.config.max_bet_gold if driver.config.max_bet_gold else 1000
 russian_path = driver.config.russian_path if driver.config.russian_path else ''
@@ -206,7 +207,6 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
                 time.time() - rs_player[event.group_id]['time'] > 30:
             await shot.send('决斗已过时，强行结算...')
             await end_game(bot, event)
-            return
         if not rs_player[event.group_id][2] and time.time() - rs_player[event.group_id]['time'] > 30:
             rs_player[event.group_id][1] = 0
             rs_player[event.group_id][2] = 0
@@ -248,7 +248,7 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
 
     if at_:
         at_ = at_[0]
-        at_player_name = await bot.get_group_member_info(group_id=event.group_id, user_id=event.user_id)
+        at_player_name = await bot.get_group_member_info(group_id=event.group_id, user_id=int(at_))
         at_player_name = at_player_name['card'] if at_player_name['card'] else at_player_name['nickname']
         msg = f'{player1_name} 向 {MessageSegment.at(at_)} 发起了决斗！请 {at_player_name} 在30秒内回复‘接受对决’ or ‘拒绝对决’，超时此次决斗作废！'
     else:
@@ -367,7 +367,7 @@ async def end_game(bot: Bot, event: GroupMessageEvent):
                                   f'\t累计败场：{lose_user["lose_count"]}\n'
                                   f'\t累计输掉金币：{lose_user["lose_gold"]}\n'
                                   f'-------------------\n'
-                                  f'哼哼，{list(bot.config.nickname)[0]}从中收取了 {float(rand)}%({fee}金币) 作为手续费！\n'
+                                  f'哼哼，{bot_name}从中收取了 {float(rand)}%({fee}金币) 作为手续费！\n'
                                   f'子弹排列：{bullet_str[:-1]}')
     rs_player[event.group_id] = {}
     with open(file, 'w', encoding='utf8') as f:
